@@ -18,14 +18,9 @@
 #  include <thread.h>
 #endif
 
-static Refcount thread_counter;
-
 void global_init(pTHX) {
-	if (!refcount_inited(&thread_counter)) {
-		refcount_init(&thread_counter, 1);
+	mark_clonable_pvs("Thread::CSP::Channel");
 
-		mark_clonable_pvs("Thread::CSP::Channel");
-	}
 	if (!PL_perl_destruct_level)
 		PL_perl_destruct_level = 1;
 
@@ -38,14 +33,6 @@ void global_init(pTHX) {
 	mark_clonable_pvs("threads::shared::tie");
 }
 
-static void thread_count_inc() {
-	refcount_inc(&thread_counter);
-}
-
-static void thread_count_dec() {
-	refcount_dec(&thread_counter);
-}
-
 void boot_DynaLoader(pTHX_ CV* cv);
 
 static void xs_init(pTHX) {
@@ -69,8 +56,6 @@ run_thread(void* arg) {
 	static const char* argv[] = { "perl", "-e", "0", NULL };
 	static const int argc = sizeof argv / sizeof *argv - 1;
 
-	thread_count_inc();
-
 	mthread* thread = (mthread*)arg;
 	struct promise* at_inc_promise = thread->at_inc;
 	struct promise* arguments = thread->arguments;
@@ -117,13 +102,10 @@ run_thread(void* arg) {
 	CATCH {
 		promise_set_exception(output, ERRSV);
 	}
-	promise_refcount_dec(output);
 
 	perl_destruct(my_perl);
 	perl_free(my_perl);
 
-	thread_count_dec();
-
 	return NULL;
 }
 
