@@ -1,12 +1,6 @@
 #define PERL_NO_GET_CONTEXT
 #include <EXTERN.h>
 #include <perl.h>
-#define NEED_mg_findext
-#include "ppport.h"
-
-#ifndef sv_derived_from_pvn
-#define sv_derived_from_pvn(sv, name, namelen, flags) sv_derived_from(sv, name)
-#endif
 
 SV* S_clone_value(pTHX_ SV* original) {
 	dSP;
